@@ -1,5 +1,5 @@
 "iclust.diagram" <- 
-function(ic,labels=NULL,short=FALSE,digits=2,cex=NULL,min.size=NULL,e.size=1,colors=c("black","blue"), main="ICLUST diagram") {
+function(ic,labels=NULL,short=FALSE,digits=2,cex=NULL,min.size=NULL,e.size=1,colors=c("black","blue"), main="ICLUST diagram",cluster.names = NULL) {
 
  
 
@@ -18,6 +18,9 @@ fixed <- fix.names(ic,var.labels)
 clusters <- fixed$ic$results
 max.len <- max(nchar((var.labels)))
 
+if(is.null(cluster.names)) cluster.names <- rownames(clusters)  #added Sept 2, 2012
+names(cluster.names) <- rownames(clusters) 
+
 length.labels <- max(max.len* .15 * cex,.25*cex)
 ##
 
@@ -41,7 +44,7 @@ done <- 0
 if (nc==1) {head <- num
            size <- num.var
            y.loc <- clusters[head,"size2"]
-	       down(clusters,head,size,y.loc,old.head= NULL,old.loc=NULL,min.size=min.size,e.size=e.size,digits=digits,cex=cex,limx=limx,limy=limy,colors=colors)
+	       down(clusters,head,size,y.loc,old.head= NULL,old.loc=NULL,min.size=min.size,e.size=e.size,digits=digits,cex=cex,limx=limx,limy=limy,colors=colors,cluster.names=cluster.names)
 	       } else {
 #the multiple cluster case           
 for(clust in 1:nc) {
@@ -55,7 +58,7 @@ for(clust in 1:nc) {
 	
 		cluster <- clusters[head,]
 		 y.loc <- clusters[head,"size2"] + done
-    	down(clusters,head,size,y.loc,old.head= NULL,old.loc=NULL,min.size=min.size,e.size=e.size,digits=digits,cex=cex,limx=limx,limy=limy,colors=colors)
+    	down(clusters,head,size,y.loc,old.head= NULL,old.loc=NULL,min.size=min.size,e.size=e.size,digits=digits,cex=cex,limx=limx,limy=limy,colors=colors,cluster.names = cluster.names)
       }  else {v.name <-names(which(ic$clusters[,clust] ==1))
       dia.rect(0,done+.5,v.name,xlim=limx,ylim=limy,cex=cex)
     
@@ -89,14 +92,17 @@ for(clust in 1:nc) {
 
     
  "dia.cluster" <- 
- function(x, y = NULL, cluster, link=NULL, digits=2,cex = cex,e.size=.6,xlim=c(0,1),ylim=c(0,1),small=FALSE) {
-   
+ function(x, y = NULL, cluster, link=NULL, digits=2,cex = cex,e.size=.6,xlim=c(0,1),ylim=c(0,1),small=FALSE,cluster.names) {
+  
 	if(!small) {
-	 text(x,y, rownames(cluster),pos=3,cex=cex)
+	 #text(x,y, rownames(cluster),pos=3,cex=cex)
+	 text(x,y, (cluster.names[rownames(cluster)]),pos=3,cex=cex)
 	 text(x,y, substitute(list(alpha) == list(a),list(a=round(cluster[1,"alpha"],digits))),cex=cex) 
-	text(x,y, substitute(list(beta) == list(b), list(b=round(cluster[1,"beta"],digits))),cex=cex,pos=1) } else { text(x,y, rownames(cluster),cex=cex) }
+	text(x,y, substitute(list(beta) == list(b), list(b=round(cluster[1,"beta"],digits))),cex=cex,pos=1) 
+	 xs <- dia.ellipse1(x,y,xlim=xlim,ylim=ylim,e.size=e.size )} else { text(x,y, (cluster.names[rownames(cluster)]),cex=cex)
+	      xs <- dia.ellipse1(x,y,xlim=xlim,ylim=ylim,e.size=e.size *.75) }
      vert <- cex*.3
-     xs <- dia.ellipse1(x,y,xlim=xlim,ylim=ylim,e.size=e.size)
+     
      left <- c(x-xs,y)
      right <- c(x+xs,y)
      top <- c(x,y+xs)
@@ -109,14 +115,14 @@ for(clust in 1:nc) {
   #down is a recursive function that draws the complete cluster structure
   
    "down" <- 
-   function(clusters,head,x,y,sign.clust=1,old.head = NULL,old.loc=NULL,digits,cex,limx,limy,min.size=1,e.size=.6,color.lines=TRUE,colors=c("black","blue")) {
+   function(clusters,head,x,y,sign.clust=1,old.head = NULL,old.loc=NULL,digits,cex,limx,limy,min.size=1,e.size=.6,color.lines=TRUE,colors=c("black","blue"),cluster.names ) {
    
   
            shift <-2
            size <- clusters[head,"size"]
 		   cluster <- clusters[head,]
 		   if(is.null(old.loc)) {link <- NULL} else {link <- old.head}   #remember the cluster that spawned this cluster
-           if(size > min.size) {c.loc <- dia.cluster(head+shift,y,cluster,link=link,digits=digits,cex=cex,e.size=e.size) } else {c.loc <- dia.cluster(head+2,y,cluster,link=link,digits=digits,cex=cex,e.size=e.size*.6,small=TRUE)}
+           if(size > min.size) {c.loc <- dia.cluster(head+shift,y,cluster,link=link,digits=digits,cex=cex,e.size=e.size,cluster.names=cluster.names) } else {c.loc <- dia.cluster(head+2,y,cluster,link=link,digits=digits,cex=cex,e.size=e.size*.6,small=TRUE,cluster.names=cluster.names)}
 
            if(!is.null(old.loc)) { 
            						if(old.loc$top[2] < c.loc$top[2]) {labels <- round(clusters[c.loc$link,"r1"],digits) } else { labels <- round(clusters[c.loc$link,"r2"],digits)}
@@ -142,7 +148,7 @@ for(clust in 1:nc) {
                		cluster <- clusters[head1,]   #get ready to go down the tree
 
                		y.shift <- clusters[head1,"size2"]
-              		down(clusters,head1,x,y+y.shift,sign.clust,old.head=head,old.loc = c.loc,min.size=min.size,e.size=e.size,digits=digits,cex=cex,limx=limx,limy=limy,colors=colors) 
+              		down(clusters,head1,x,y+y.shift,sign.clust,old.head=head,old.loc = c.loc,min.size=min.size,e.size=e.size,digits=digits,cex=cex,limx=limx,limy=limy,colors=colors,cluster.names=cluster.names) 
               		} 
               		 
               		if(size2==1) {
@@ -157,7 +163,7 @@ for(clust in 1:nc) {
                			head <- which(rownames(clusters)== clusters[head,2]) 
                			cluster <- clusters[head,]
                			y.shift <- clusters[head,"size1"]
-               			down(clusters,head,x,y-y.shift,sign.clust,old.head=old.head,old.loc = c.loc,min.size=min.size,e.size=e.size,digits=digits,cex=cex,limx=limx,limy=limy,colors=colors)
+               			down(clusters,head,x,y-y.shift,sign.clust,old.head=old.head,old.loc = c.loc,min.size=min.size,e.size=e.size,digits=digits,cex=cex,limx=limx,limy=limy,colors=colors,cluster.names=cluster.names)
                			
               					 } 
              }
