@@ -1,5 +1,5 @@
 "df2latex" <- 
-function(x,digits=2,rowlabels=TRUE,apa=TRUE,short.names=TRUE,font.size ="scriptsize", heading="A table from R",caption="df2latex") {
+function(x,digits=2,rowlabels=TRUE,apa=TRUE,short.names=TRUE,font.size ="scriptsize",big.mark=NULL, heading="A table from R",caption="df2latex",label="default") {
 #first set up the table
  nvar <- dim(x)[2]
 comment <- paste("%", match.call())
@@ -7,7 +7,7 @@ header <- paste("\\begin{",font.size,"} \\begin{table}[htdp]",
 "\\caption{",caption,"}
 \\begin{center}
 \\begin{tabular}",sep="")
-if(rowlabels) {header <- c(header,"{l",rep("r",(nvar)),"}\n")} else {header <- c(header,"{",rep("r",(nvar)),"}\n")}
+if(rowlabels) {header <- c(header,"{l",rep("r",(nvar)),"}\n")} else {header <- c(header,"{",rep("r",(nvar+1)),"}\n")} 
 if(apa) {header <- c(header,
 "\\multicolumn{",nvar,"}{l}{",heading,"}",
 '\\cr \n \\hline ')
@@ -15,7 +15,7 @@ footer <- paste(" \\hline ")}  else {footer <- NULL}
 footer <- paste(footer,"
 \\end{tabular}
 \\end{center}
-\\label{default}
+\\label{",label,"}
 \\end{table} 
 \\end{",font.size,"}
 ",sep=""
@@ -31,9 +31,10 @@ if(!is.null(digits)) {if(is.numeric(x) ) {x <- round(x,digits=digits)} else {x <
  
  if(apa)  {allnames <- c("Variable  &  ",names1,lastname," \\hline \n")} else {if(rowlabels) {allnames <- c("  &  ",names1,lastname,"\\cr \n")} else {
              allnames <- c(names1,lastname,"\\cr \n")}}
- x <- format(x)  #to keep the digits the same
+if(is.null(big.mark)) { x <- format(x)} else   #to keep the digits the same
+                      {x <- prettyNum(x,big.mark=",")}
  value <- apply(x,1,paste,collapse="  &  ") #insert & between columns
- if(rowlabels) value <- paste(names(value),"  & ",value)
+ if(rowlabels) {value <- paste(sanitize.latex(names(value)),"  & ",value)} else {value <- paste("  & ",value)}
  values <- paste(value, "\\cr", "\n")  #add \\cr at the end of each row
 
  #now put it all together
@@ -46,27 +47,28 @@ if(!is.null(digits)) {if(is.numeric(x) ) {x <- round(x,digits=digits)} else {x <
  }
  
  
-"cor2latex" <- function(x,digits=2,rowlabels=TRUE,lower=TRUE,apa=TRUE,short.names=TRUE,font.size ="scriptsize",heading="A correlation table from R",caption="cor2latex") {
+"cor2latex" <- function(x,digits=2,rowlabels=TRUE,lower=TRUE,apa=TRUE,short.names=TRUE,font.size ="scriptsize",heading="A correlation table from the psych package in R",caption="cor2latex",label="default") {
 if(nrow(x) > ncol(x) ) {x <- cor(x,use="pairwise")}
 r <- round(x,digits)
 r <- format(r,nsmall=digits)  #this converts to character but keeps the right number of digits
 if(lower) {r[upper.tri(r)] <- "~"} else {r[lower.tri(r)] <- "~"} 
-return(df2latex(r,digits=NULL,rowlabels=rowlabels,apa=apa,short.names=short.names,font.size=font.size,heading=heading,caption=caption))
+return(df2latex(r,digits=NULL,rowlabels=rowlabels,apa=apa,short.names=short.names,font.size=font.size,heading=heading,caption=caption,label=label))
 }
 
 "fa2latex" <- 
-function(f,digits=2,rowlabels=TRUE,apa=TRUE,short.names=FALSE,font.size ="tiny", heading="A factor analysis table from R",caption="fa2latex") {
+function(f,digits=2,rowlabels=TRUE,apa=TRUE,short.names=FALSE,font.size ="scriptsize", heading="A factor analysis table from the psych package in R",caption="fa2latex",label="default") {
 x <- unclass(f$loadings)
 if(!is.null(f$Phi)) {Phi <- f$Phi} else {Phi <- NULL}
-nfactors <-ncol(x)
+nfactors <- ncol(x)
 
 if(nfactors > 1) {if(is.null(Phi)) {h2 <- rowSums(x^2)} else {h2 <- diag(x %*% Phi %*% t(x)) }} else {h2 <-x^2}
 u2 <- 1- h2
 vtotal <- sum(h2 + u2)
-x <- data.frame(x,h2=h2,u2=u2)
+
+if(!is.null(f$complexity)) {x <- data.frame(x,h2=h2,u2=u2,com=f$complexity) } else {x <- data.frame(x,h2=h2,u2=u2)}
 #first set up the table
  nvar <- dim(x)[2]
-comment <- paste("%", match.call())
+comment <- paste("% Called in the psych package ", match.call())
 header <- paste("\\begin{",font.size,"} \\begin{table}[htdp]",
 "\\caption{",caption,"}
 \\begin{center}
@@ -79,7 +81,7 @@ if(apa) {footer <- paste(" \\hline ")}
 footer <- paste(footer,"
 \\end{tabular}
 \\end{center}
-\\label{default}
+\\label{",label,"}
 \\end{table} 
 \\end{",font.size,"}
 ",sep=""
@@ -96,7 +98,7 @@ footer <- paste(footer,"
  if(apa)  {allnames <- c("Variable  &  ",names1,lastname," \\hline \n")} else {allnames <- c("  &  ",names1,lastname,"\\cr \n")}
  x <- format(x)  #to keep the digits the same
  value <- apply(x,1,paste,collapse="  &  ") #insert & between columns
- if(rowlabels) value <- paste(names(value),"  & ",value)
+ if(rowlabels) value <- {paste(sanitize.latex(names(value)),"  & ",value)} else {paste("  &  ",value)}
  values <- paste(value, "\\cr", "\n")  #add \\cr at the end of each row
 
  #now put it all together
@@ -140,10 +142,14 @@ footer <- paste(footer,"
  
  
  "irt2latex" <- 
-function(f,digits=2,rowlabels=TRUE,apa=TRUE,short.names=FALSE,font.size ="tiny", heading="An IRT factor analysis table from R",caption="fa2latex") {
-i <- 1  
+function(f,digits=2,rowlabels=TRUE,apa=TRUE,short.names=FALSE,font.size ="scriptsize", heading="An IRT factor analysis table from R",caption="fa2latex" ,label="default") {
+nf <- length(f$plot$sumInfo)   #create nf tables 
+for(i in (1:nf)) { 
 x <- f$plot$sumInfo[[i]]
-
+if(nf>1) {
+rowmax <- apply(x,1,max, na.rm=TRUE)
+ rowmax <- which(rowmax <.001,arr.ind=TRUE) 
+ if(!is.null(rowmax)) x <- x[-rowmax,]}
 #first set up the table
  nvar <- ncol(x)
 comment <- paste("%", match.call())
@@ -160,13 +166,12 @@ if(apa) {footer <- paste(" \\hline ")}
 footer <- paste(footer,"
 \\end{tabular}
 \\end{center}
-\\label{default}
+\\label{",label,"}
 \\end{table} 
 \\end{",font.size,"}
 ",sep=""
 )
 
-
 #now put the data into it
  x <- round(x,digits=digits)
  cname <- colnames(x)
@@ -177,11 +182,9 @@ footer <- paste(footer,"
  if(apa)  {allnames <- c("Item  &  ",names1,lastname," \\hline \n")} else {allnames <- c("  &  ",names1,lastname,"\\cr \n")}
  x <- format(x)  #to keep the digits the same
  value <- apply(x,1,paste,collapse="  &  ") #insert & between columns
- if(rowlabels) value <- paste(names(value),"  & ",value)
+ if(rowlabels) value <- paste(sanitize.latex(names(value)),"  & ",value)
  values <- paste(value, "\\cr", "\n")  #add \\cr at the end of each row
 
-
-
  #now put it all together
  cat(comment,"\n")  #a comment field saying where the data came from
  cat(header)   #the header information
@@ -200,8 +203,18 @@ footer <- paste(footer,"
  cat(summary)
  
  cat(footer)   #close it up with a footer
-
+ }
  }
  
  
+ #adapted from various sources, including xtable
+"sanitize.latex" <- 
+function(astring) {
+result <- astring
+result <- gsub("&", "\\&", result, fixed = TRUE)
+result <- gsub("_", "\\_", result, fixed = TRUE)
+result <- gsub("%", "\\%", result, fixed = TRUE)
+return(result)
+}
+ 
 
