@@ -57,11 +57,9 @@ conf.level <- alpha
     result$fit <-1-rstar2/r2
     result$fit.off <- 1-rstar.off/r2.off
     result$sd <- sd(as.vector(residual)) #this is the none sample size weighted root mean square residual
-   
-    
-    
-    
     result$factors <- nfactors
+    
+    result$complexity <- (apply(f,1,function(x) sum(x^2)))^2/apply(f,1,function(x)sum(x^4))
   
     diag(model) <- diag(r)  
     model <- cor.smooth(model)  #this replaces the next few lines with a slightly cleaner approach
@@ -186,7 +184,7 @@ conf.level <- alpha
                       R2[abs(R2) > 1] <- NA
                       R2[R2 <= 0] <- NA
                      }
-     if ((max(R2) > (1 + .Machine$double.eps)) ) {message("The estimated weights for the factor scores are probably incorrect.  Try a different factor extraction method.")}
+     if ((max(R2,na.rm=TRUE) > (1 + .Machine$double.eps)) ) {message("The estimated weights for the factor scores are probably incorrect.  Try a different factor extraction method.")}
      }
       r.scores <- cov2cor(t(w) %*% r %*% w) 
       result$r.scores <- r.scores 
