@@ -19,6 +19,7 @@ if (is.matrix(x) | is.data.frame(x)) {
               }
 t <- fa(r,nfactors=nfactors,n.obs=n.obs,...)
 nf <- dim(t$loadings)[2]
+
  diffi <- list() 
      #flag <- which(abs(t$loadings) > 1,arr.ind=TRUE)
      #this throws an error if a Heywood case
@@ -26,6 +27,20 @@ nf <- dim(t$loadings)[2]
      }
      
 discrim <- t$loadings/sqrt(1-t$loadings^2)
+if(any(is.nan(discrim))) {
+      for (i in 1:nf) {
+         bad <- which(is.nan(discrim[,i]))
+        if(length( bad) > 0) { warning("A discrimination  with a NaN value was replaced with the maximum discrimination for factor ", i, " and  item(s)  ",bad, "\nexamine the factor analysis object (fa)  to identify the Heywood case. \nThe item informations are probably suspect as well for this factor.  \nYou might try a different factor extraction technique. ") 
+          discrim[is.nan(discrim[,i]),i] <- max(discrim[,i],na.rm=TRUE) 
+          diffi[[i]][bad,] <- tau[bad,]
+         
+         }
+        }}
+        
+
+     
+
+
 class(diffi) <- NULL
 class(discrim) <- NULL
 tl <- t$loadings
@@ -61,6 +76,12 @@ diffi <- list()
      for (i in 1:nf) {diffi[[i]]  <- tau/sqrt(1-f$loadings[,i]^2)
      }
 discrim <- f$loadings/sqrt(1-f$loadings^2)
+if(any(is.nan(discrim))) {bad <- which(is.nan(discrim),arr.ind=TRUE)
+      if(length(bad) > 0) { warning("An discrimination  with a NaN value was replaced with the maximum discrimination for item(s)  ",bad, "\nexamine the factor analysis object (fa)  to identify the Heywood case") }
+          for (i in 1:nf) {
+          discrimin[is.nan(discrim[,i])] <- max(discrimin[,i],na.rm=TRUE) 
+        }}
+    
 irt <- list(difficulty=diffi,discrimination=discrim)
 result <- list(irt=irt,fa = f,rho=r,tau=tau,n.obs=n.obs,Call=cl)
 
