@@ -1,9 +1,10 @@
 "principal" <-
-function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, covar=FALSE,scores=FALSE,missing=FALSE,impute="median",oblique.scores=TRUE,method="regression",...) {
+function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, covar=FALSE,scores=TRUE,missing=FALSE,impute="median",oblique.scores=TRUE,method="regression",...) {
    cl <- match.call()
    n <- dim(r)[2]
   
    if (n!=dim(r)[1]) {
+                    raw <- TRUE
       				n.obs <- dim(r)[1] 
       				if(scores) {x.matrix <- as.matrix(r)  #matrices are required for the substitution to work
     
@@ -18,6 +19,7 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, covar=FALSE,s
        				 # 2011.12.21  added the covar option
       if(!covar) {r <- cor(r,use="pairwise")} else r <- cov(r,use="pairwise")  # if given a rectangular matrix, then find the correlations or covariances first
              } else {
+                     raw <- FALSE
      				if(!is.matrix(r)) {  r <- as.matrix(r)}
      				 sds <- sqrt(diag(r))    #convert covariance matrices to correlation matrices
                      if(!covar) r <- r/(sds %o% sds)  }  #added June 9, 2008
@@ -52,6 +54,7 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, covar=FALSE,s
    	if (rotate=="varimax" |rotate=="Varimax" | rotate=="quartimax" | rotate =="bentlerT" | rotate =="geominT" |rotate =="bifactor" ||rotate =="targetT" ) { 
    	if (!require(GPArotation)) {stop("I am sorry, to do these rotations requires the GPArotation package to be installed")}
    	       #varimax is from the stats package, Varimax is from GPArotations
+   	       colnames(loadings) <- paste("RC",1:nfactors,sep='')  #to remind us that we are rotating the components 
    			rotated <- do.call(rotate,list(loadings,...))
    			loadings <- rotated$loadings
    			 Phi <- NULL} else { 
@@ -66,7 +69,9 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, covar=FALSE,s
      			                     
      			if (rotate =="oblimin"| rotate=="quartimin" | rotate== "simplimax" | rotate =="geominQ"  | rotate =="bentlerQ" |rotate == "biquartimin" |rotate == "targetQ" |rotate == "TargetQ" ) {
      				if (!require(GPArotation)) {warning("I am sorry, to do these rotations requires the GPArotation package to be installed")
-     				Phi <- NULL} else { ob  <- try(do.call(rotate,list(loadings,...) ))
+     				Phi <- NULL} else {
+     				 colnames(loadings) <- paste("TC",1:nfactors,sep='')  #to remind us that we are Transforming the components 
+     				  ob  <- try(do.call(rotate,list(loadings,...) ))
      				          if(class(ob)== as.character("try-error"))  {warning("The requested transformaton failed, Promax was used instead as an oblique transformation")
      				                  ob <- Promax(loadings)}
      				                 
@@ -95,7 +100,7 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, covar=FALSE,s
      class(loadings) <- "loadings"
      
     result$n.obs <- n.obs
-    stats <- factor.stats(r,loadings,Phi,n.obs)
+    stats <- factor.stats(r,loadings,Phi,n.obs,fm="pc")
     class(result) <- c("psych", "principal") 
     result$fn <- "principal"
     result$loadings <- loadings
@@ -122,7 +127,7 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, covar=FALSE,s
                        Structure <- loadings %*% Phi} else {Structure <- loadings
                        }
     
-    if(scores) {result$scores <- factor.scores(scale(x.matrix),Structure,method=method)  # method = method added Nov 20, 2011
+    if(scores && raw) {result$scores <- factor.scores(scale(x.matrix),Structure,method=method)  # method = method added Nov 20, 2011
                 result$weights<- result$scores$weights
                 result$scores <- result$scores$scores}
     return(result)
@@ -140,4 +145,6 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, covar=FALSE,s
   #modified August 25 to return result$stats
   #modified November 20, 2011 to allow multiple scoring approaches to give component scores
   #modified December 21, 2011 to allow for finding the pc of covariances 
-  #modified June 19, 2012 to fix a missing value problem reported by Neil Stewart
\ No newline at end of file
+  #modified June 19, 2012 to fix a missing value problem reported by Neil Stewart
+  #modified February 9, 2013 to label the type of rotation/transformation (as is documented but not implemented)
+  #modified February 25, 2013 to make scores=TRUE the default 
\ No newline at end of file
